@@ -1,5 +1,4 @@
 #![allow(unused_doc_comments)]
-
 use const_array_attrs::sorted;
 use const_frac::Frac;
 use crate:: {
@@ -38,7 +37,8 @@ const AT2BASE: Conv = GRAM_FORCE2NEWTON.mul(NEWTON2BASE).mul(Conv(Frac::from_exp
 const PSI2BASE: Conv = POUND2GRAM.mul(GRAM_FORCE2NEWTON).mul(NEWTON2BASE).div(INCH2METER.mul(INCH2METER));
 
 #[sorted]
-pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
+#[doc = include_str!("def.md")]
+pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 223] = [
     // dimensionless
 
     /// ‐ hyphen
@@ -186,6 +186,10 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
     ("\u{330C}", (Conv(Frac::from_ratio(1, 5, 0), ZERO), DynDim::new(Mass::CODE))),
     // T
     ("s", (Conv(ONE, ZERO), DynDim::new(Time::CODE))),
+    ("min", (Conv(Frac::from_int(60), ZERO), DynDim::new(Time::CODE))),
+    ("h", (Conv(Frac::from_int(60 * 60), ZERO), DynDim::new(Time::CODE))),
+    ("day", (Conv(Frac::from_int(60 * 60 * 24), ZERO), DynDim::new(Time::CODE))),
+    ("year", (Conv(Frac::from_int(31_557_600), ZERO), DynDim::new(Time::CODE))),
     /// ㎰
     ("\u{33B0}", (Conv(Frac::from_exp10(-12), ZERO), DynDim::new(Time::CODE))),
     /// ㎱
@@ -322,11 +326,11 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
     ("\u{33A5}", (Conv(ONE, ZERO), DynDim::new(Volume::CODE))),
     /// ㎦
     ("\u{33A6}", (Conv(Frac::from_exp10(9), ZERO), DynDim::new(Volume::CODE))),
-    ("gal(en)", (
+    ("gal.en", (
         Conv(Frac::from_ratio(4_546_09, 1, -8), ZERO),
         DynDim::new(Volume::CODE)
     )),
-    ("gal(us)", (
+    ("gal.us", (
         Conv(Frac::from_ratio(3_785_412, 1, -9), ZERO),
         DynDim::new(Volume::CODE)
     )),
@@ -354,6 +358,11 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
         Conv(Frac::from_ratio(1852, 3600, 0), ZERO),
         DynDim::new(Velocity::CODE)
     )),
+    /// ㏏
+    ("\u{33CF}", (
+        Conv(Frac::from_ratio(1852, 3600, 0), ZERO),
+        DynDim::new(Velocity::CODE)
+    )),
     // Acceleration
     /// ㎨
     ("\u{33A8}", (Conv(ONE, ZERO), DynDim::new(Velocity::CODE))),
@@ -428,14 +437,14 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
         DynDim::new(Energy::CODE)
     )),
     // Radiation
-    ("Gy", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Enthalpy::CODE))),
+    ("Gy", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(SpecificEnthalpy::CODE))),
     /// ㏉
-    ("\u{33C9}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Enthalpy::CODE))),
-    ("Sv", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Enthalpy::CODE))),
+    ("\u{33C9}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(SpecificEnthalpy::CODE))),
+    ("Sv", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(SpecificEnthalpy::CODE))),
     /// ㏜
-    ("\u{33DC}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(Enthalpy::CODE))),
+    ("\u{33DC}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(SpecificEnthalpy::CODE))),
     /// ㍕
-    ("\u{3355}", (Conv(Frac::from_exp10(1), ZERO), DynDim::new(Enthalpy::CODE))),
+    ("\u{3355}", (Conv(Frac::from_exp10(1), ZERO), DynDim::new(SpecificEnthalpy::CODE))),
     /// ㍖
     ("\u{3356}", (
         Conv(Frac::from_ratio(258, 1, -5), ZERO),
@@ -517,6 +526,8 @@ pub const DEFAULT_UNIT_DEF: [(&str, (Conv, DynDim)); 216] = [
     /// ㏝
     ("\u{33DD}", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(MagneticFlux::CODE))),
     ("T", (Conv(Frac::from_exp10(3), ZERO), DynDim::new(MagneticFluxDensity::CODE))),
+    ("P", (Conv(Frac::from_exp10(2), ZERO), DynDim::new(Viscosity::CODE))),
+    ("St", (Conv(Frac::from_exp10(-4), ZERO), DynDim::new(KinematicViscosity::CODE))),
 ];
 
 #[cfg(test)]
